@@ -2,6 +2,7 @@ import os
 import platform
 import distutils.sysconfig
 import shutil
+from pathlib import Path
 
 from . import progress
 
@@ -9,6 +10,9 @@ from . import progress
 # If blas was not installed, this doesn't really do anything
 if platform.system() == "Windows":
 	import win32api
-	win32api.SetDllDirectory(os.path.join(distutils.sysconfig.get_python_lib(), "librapid", "blas"))
+	this_directory = Path(__file__).parent
+
+	print("Loading DLL from", os.path.join(this_directory, "librapid", "blas"))
+	win32api.SetDllDirectory(os.path.join(this_directory, "librapid", "blas"))
 
 from librapid_ import *
