@@ -1,8 +1,7 @@
 #include <iostream>
 #include <chrono>
 
-#define ND_MAX_DIMS 10
-#define ND_NUM_THREADS 32
+#define LIBRAPID_MAX_DIMS 10
 // #define LIBRAPID_CBLAS
 
 #include "ndarray_benchmarks.hpp"
@@ -10,19 +9,20 @@
 
 int main()
 {
-	auto lhs = librapid::ndarray::basic_ndarray<double>(librapid::ndarray::extent({2, 2}), 0);
-	auto rhs = librapid::ndarray::basic_ndarray<double>(librapid::ndarray::extent({2}), 0);
+	auto lhs = librapid::ndarray(librapid::extent({10, 10}), 0);
+	auto rhs = librapid::ndarray(librapid::extent({10, 10}), 0);
 
-	for (nd_int i = 0; i < lhs.size(); i++)
+	for (lr_int i = 0; i < lhs.size(); i++)
 		lhs.set_value(i, i + 1);
 
-	for (nd_int i = 0; i < rhs.size(); i++)
+	for (lr_int i = 0; i < rhs.size(); i++)
 		rhs.set_value(i, i + 1);
 
 	std::cout << lhs.str() << "\n";
 	std::cout << rhs.str() << "\n";
 	auto start = TIME;
 	auto res = lhs.dot(rhs);
+	res = lhs + rhs;
 	auto end = TIME;
 
 	std::cout << end - start << "ms\n";
@@ -31,5 +31,9 @@ int main()
 
 	// benchmark_ndarray();
 
+	std::cout << librapid::math::round(-0.05, 1) << "\n";
+	std::cout << librapid::math::round(-0.5) << "\n";
+	std::cout << librapid::math::round(0.44, 1) << "\n";
+
 	return 0;
 }
